<?php

/**
 * Scaffold_Extension_ImageCache
 *
 * Process imagecache preset.
 * 
 * @package 		Drupal
 * @author 			Julien De Luca <julien@likwid.fr>
 */
class Scaffold_Extension_ImageCache extends Scaffold_Extension_AbsoluteUrls
{
	private $source;
	
	/**
	 * @access public
	 * @param $source
	 * @return string
	 */
	public function initialize($source,$scaffold)
	{
		$this->source = $source;
	}
	
	/**
	 * Registers a custom CSS function.
	 * @access public
	 * @param $functions
	 * @return array
	 */
	public function register_function($functions)
	{
		$functions->register('imagecache',array($this,'imagecache'));
	}
	
	/**
	 * Process imagecache preset.
	 *
	 * @param $url Url of the image
	 * @param $presetname The imagecache preset name
	 * @return string
	 */
	public function imagecache($url,$presetname)
	{
		$url = $this->unquote($url);
		$presetname = $this->unquote($presetname);
		
		$relative_path = str_replace($_SERVER['DOCUMENT_ROOT'],'',dirname($this->source->path));
		$absolute = $this->resolve_absolute_path($relative_path,$url);

		$imagecache_url = imagecache_create_url($presetname, $absolute);

		return 'url('.$imagecache_url.')';
	}
	
	/**
	 * Resolve a url path
	 * @access private
	 * @param $relative_path Document root relative path to the original CSS file
	 * @param $path The CSS url path to resolve
	 */
	private function resolve_absolute_path($relative_path,$path)
	{
		# Relative path to the file
		$relative = $this->up_directory(
			$relative_path, 
			substr_count($path, '..'.DIRECTORY_SEPARATOR, 0)
		); 
		
		# Absolute path				
		return $relative.str_replace('..'.DIRECTORY_SEPARATOR,DIRECTORY_SEPARATOR,$path);
	}
	
	/**
	 * Takes a path, and goes back x number of directories.
	 * @access public
	 * @param $path The path
	 * @param $n The number of directories to go back
	 * @return string
	 */
	public function up_directory($path,$n)
	{
		$exploded = explode(DIRECTORY_SEPARATOR,$path);
		$exploded = array_slice($exploded, 0, (count($exploded) - $n) );
		return implode(DIRECTORY_SEPARATOR,$exploded);
	}

	/**
	 * Removes surrounding quotes from a string
	 * @access public
	 * @param $string
	 * @return string
	 */
	public function unquote($string)
	{
		return trim($string,"\"' ");
	}
}